package com.zhyc.module.biosafety.mapper;

import java.util.List;
import com.zhyc.module.biosafety.domain.Disinfect;
import org.apache.ibatis.annotations.Mapper;

/**
 * 消毒记录Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Mapper
public interface DisinfectMapper 
{
    /**
     * 查询消毒记录
     * 
     * @param id 消毒记录主键
     * @return 消毒记录
     */
    public Disinfect selectDisinfectById(Long id);

    /**
     * 查询消毒记录列表
     * 
     * @param disinfect 消毒记录
     * @return 消毒记录集合
     */
    public List<Disinfect> selectDisinfectList(Disinfect disinfect);

    /**
     * 新增消毒记录
     * 
     * @param disinfect 消毒记录
     * @return 结果
     */
    public int insertDisinfect(List<Disinfect> disinfect);

    /**
     * 修改消毒记录
     * 
     * @param disinfect 消毒记录
     * @return 结果
     */
    public int updateDisinfect(Disinfect disinfect);

    /**
     * 删除消毒记录
     * 
     * @param id 消毒记录主键
     * @return 结果
     */
    public int deleteDisinfectById(Long id);

    /**
     * 批量删除消毒记录
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDisinfectByIds(Long[] ids);
}
