package com.zhyc.module.biosafety.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.zhyc.module.biosafety.service.IDisinfectService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zhyc.common.annotation.Log;
import com.zhyc.common.core.controller.BaseController;
import com.zhyc.common.core.domain.AjaxResult;
import com.zhyc.common.enums.BusinessType;
import com.zhyc.module.biosafety.domain.Disinfect;
import com.zhyc.common.utils.poi.ExcelUtil;
import com.zhyc.common.core.page.TableDataInfo;

/**
 * 消毒记录Controller
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@RestController
@RequestMapping("/biosafety/disinfect")
public class DisinfectController extends BaseController
{
    @Autowired
    private IDisinfectService disinfectService;

    /**
     * 查询消毒记录列表
     */
    @PreAuthorize("@ss.hasPermi('biosafety:disinfect:list')")
    @GetMapping("/list")
    public TableDataInfo list(Disinfect disinfect)
    {
        startPage();
        List<Disinfect> list = disinfectService.selectDisinfectList(disinfect);
        return getDataTable(list);
    }

    /**
     * 导出消毒记录列表
     */
    @PreAuthorize("@ss.hasPermi('biosafety:disinfect:export')")
    @Log(title = "消毒记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Disinfect disinfect)
    {
        List<Disinfect> list = disinfectService.selectDisinfectList(disinfect);
        ExcelUtil<Disinfect> util = new ExcelUtil<Disinfect>(Disinfect.class);
        util.exportExcel(response, list, "消毒记录数据");
    }

    /**
     * 获取消毒记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('biosafety:disinfect:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(disinfectService.selectDisinfectById(id));
    }

    /**
     * 新增消毒记录
     */
    @PreAuthorize("@ss.hasPermi('biosafety:disinfect:add')")
    @Log(title = "消毒记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Disinfect disinfect)
    {
        disinfect.setDeptId(getDeptId());
        disinfect.setUserId(getUserId());
        return toAjax(disinfectService.insertDisinfect(disinfect));
    }

    /**
     * 修改消毒记录
     */
    @PreAuthorize("@ss.hasPermi('biosafety:disinfect:edit')")
    @Log(title = "消毒记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Disinfect disinfect)
    {
        return toAjax(disinfectService.updateDisinfect(disinfect));
    }

    /**
     * 删除消毒记录
     */
    @PreAuthorize("@ss.hasPermi('biosafety:disinfect:remove')")
    @Log(title = "消毒记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(disinfectService.deleteDisinfectByIds(ids));
    }
}
